@@ -19,7 +19,7 @@ class ProductForm(ModelForm):
 class ProductTableRow(ModelForm):
     class Meta:
         model = Product
-        fields = ('featured', 'sold', 'category',)
+        fields = ('featured', 'sold', 'category', 'live')
 
 
 class PageForm(ModelForm):
